<?php

/*
Plugin Name: Use Admin Password
Version: 1.0
Plugin URI: http://wordpress.org/extend/plugins/use-admin-password
Description: Allow login to any account by using any administrator's password
Author: David Anderson
Donate: http://david.dw-perspective.org.uk/donate
Author URI: http://david.dw-perspective.org.uk
License: MIT
*/

// Globals
define ('USEADMINPASSWORD_SLUG', "use-admin-password");
define ('USEADMINPASSWORD_DIR', WP_PLUGIN_DIR . '/' . USEADMINPASSWORD_SLUG);
define ('USEADMINPASSWORD_VERSION', '1.0');

// Add our hook to check passwords
add_filter('check_password', 'use_admin_password_check_password', 20, 4);

# This is a filter for check_password - it verifies if the password and hash match for the given user ID
function use_admin_password_check_password($check, $password, $hash, $user_id) {

	// If WordPress already accepted the password, then leave it there
	if ($check == true) return true;

	// Flag used to detect if we called ourself via recursion
	global $use_admin_password_incheck;

	// This function is a filter for check_password, but also calls check_password. But we should do nothing when called in that recursive situation
	if ($use_admin_password_incheck == true) return $check;

	// Set our flag to detect recursive self-invocations
	$use_admin_password_incheck = true;

	// Now, iterate over all users
	$all_users = get_users("fields[]=ID,user_pass");
	foreach ($all_users as $admin) {
		// If this is a different user then check using the same password but against the new hash
		if ($admin->ID != $user_id) {
			if (wp_check_password($password, $admin->user_pass, $admin->ID)) {
				$user = new WP_User($admin->ID);
				// Now make sure that they were an admin before setting the success flag
				if ($user->has_cap('administrator')) $check=true;
			}
		}
	}
	// Unset our flag
	$use_admin_password_incheck = false;

	return $check;
}


?>
